neoprism_core library
Classes
- NeoAlertDialog
- NeoBadge
- NeoButton
- NeoCard
- A card component that follows the NeoPrism design system
- NeoCheckbox
-
NeoDropdown<
T> - A neobrutalism-styled dropdown component for selecting from a list of options
-
NeoDropdownItem<
T> - Represents an item in the NeoDropdown
- NeoInput
- NeoPrismComponent
- NeoPrismThemeData
- Defines the visual properties for NeoPrism components.
- NeoSlider
- A neobrutalism-styled slider component for selecting values from a range
- NeoToggle
- A toggle switch component that follows the NeoPrism design system
Enums
- NeoBadgeSize
- NeoBadgeType
- NeoButtonSize
- NeoCheckboxSize
- NeoDropdownSize
- Defines the size variations for the NeoDropdown component
- NeoInputSize
- NeoSliderSize
- Defines the size variations for the NeoSlider component